@@ -27,13 +27,10 @@
 #include "ktimer.h"
 #include <config-ktimer.h>
 
-static const char description[] =
-        I18N_NOOP("KDE Timer");
-
 int main( int argc, char **argv )
 {
     QApplication app(argc, argv);
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     /**
      * enable high dpi support
      */
@@ -42,10 +39,10 @@ int main( int argc, char **argv )
     Kdelibs4ConfigMigrator migrate(QStringLiteral("ktimer"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("ktimerrc"));
     migrate.migrate();
-
+#endif
     KLocalizedString::setApplicationDomain("ktimer");
     KAboutData aboutData( QStringLiteral("ktimer"), i18n("KTimer"),
-                          QStringLiteral(KTIMER_VERSION), i18n(description), KAboutLicense::GPL,
+                          QStringLiteral(KTIMER_VERSION), i18n("KDE Timer"), KAboutLicense::GPL,
                           i18n("(c) 2001, Stefan Schimanski"),
                           QStringLiteral("https://utils.kde.org/projects/ktimer/"));
     aboutData.addAuthor(i18n("Stefan Schimanski"),QString(), QStringLiteral("schimmi@kde.org"));
